@@ -115,6 +115,27 @@ namespace Rcpp{
             }
             return res ;
         }
+        
+        /**
+        * Get an object from the environment
+        *
+        * @param name symbol name to call
+        *
+        * @return a SEXP (possibly R_NilValue)
+        */
+        SEXP get(Symbol name) const {
+            SEXP env = Storage::get__() ;
+            SEXP res = Rf_findVarInFrame( env, name ) ;
+            
+            if( res == R_UnboundValue ) return R_NilValue ;
+            
+            /* We need to evaluate if it is a promise */
+            if( TYPEOF(res) == PROMSXP){
+                res = Rf_eval( res, env ) ;
+            }
+            return res ;
+        }
+        
 
         /**
          * Get an object from the environment or one of its
@@ -136,6 +157,29 @@ namespace Rcpp{
             }
             return res ;
         }
+        
+        /**
+        * Get an object from the environment or one of its
+        * parents
+        *
+        * @param name symbol name to call
+        */
+        SEXP find(Symbol name) const{
+            SEXP env = Storage::get__() ;
+            SEXP res = Rf_findVar( name, env ) ;
+            
+            if( res == R_UnboundValue ) {
+                // Pass on the const char* to the RCPP_EXCEPTION_CLASS's
+                // const std::string& requirement
+                throw binding_not_found(name.c_str()) ;
+            }
+            
+            /* We need to evaluate if it is a promise */
+            if( TYPEOF(res) == PROMSXP){
+                res = Rf_eval( res, env ) ;
+            }
+            return res ;
+        }
 
         /**
          * Indicates if an object called name exists in the
@@ -203,7 +247,7 @@ namespace Rcpp{
                     Shield<SEXP> call( Rf_lang2(internalSym,
                             Rf_lang4(removeSym, Rf_mkString(name.c_str()), Storage::get__(), Rf_ScalarLogical( FALSE ))
                         ) );
-                    Rf_eval( call, R_GlobalEnv ) ;
+                    Rcpp_eval( call, R_GlobalEnv ) ;
                 }
             } else{
                 throw no_such_binding(name) ;
